import { DOCUMENT } from '@angular/common';
import * as i0 from '@angular/core';
import { Injectable, NgModule, Inject } from '@angular/core';
import { forkJoin, Observable } from 'rxjs';

/**
 * @license
 * Copyright (c) Nelson Dominguez All Rights Reserved.
 *
 * Use of this source code is governed by a MIT-style license that
 * can found in the LICENSE file at the root of this project.
 */
function noop(...args) {
    return undefined;
}
const NGX_DEFAULT_LOAD_SCRIPT_CONFIG = {
    async: true,
    skipError: true,
    skipAbort: true,
    onError: noop,
    onLoad: noop,
    onAbort: noop,
};
/**
 * Configuration service to
 *
 * @publicApi
 */
class NgxDynamicScriptLoaderConfig {
    constructor() {
        /**
         * Value for the `async` attribute of the target {@link HTMLScriptElement}.
         *
         * @default true
         */
        this.async = NGX_DEFAULT_LOAD_SCRIPT_CONFIG.async;
        /**
         * Whether to throw an error when loading a {@link NgxDynamicScript} failed.
         * `true` for throwing an error; `false` for skipping throwing the error.
         *
         * @note
         * When this field is set to `true` using the {@link NgxDynamicScriptLoader#loadScripts} method,
         * and loading a single script fails, all other queued scripts are stopped from loading.
         *
         * @default true
         */
        this.skipError = NGX_DEFAULT_LOAD_SCRIPT_CONFIG.skipError;
        /**
         * Whether to throw an error when loading a {@link NgxDynamicScript} failed.
         * `true` for throwing an error; `false` for skipping throwing the error.
         *
         * @note
         * When this field is set to `true` using the {@link NgxDynamicScriptLoader#loadScripts} method,
         * and loading a single script fails, all other queued scripts are stopped from loading.
         *
         * @default true
         */
        this.skipAbort = NGX_DEFAULT_LOAD_SCRIPT_CONFIG.skipAbort;
        /**
         * Callback that fires when an error occures while loading the script.
         *
         * @default noop
         */
        this.onError = NGX_DEFAULT_LOAD_SCRIPT_CONFIG.onError;
        /**
         * Callback that fires when canceling loading the script.
         *
         * @default noop
         */
        this.onAbort = NGX_DEFAULT_LOAD_SCRIPT_CONFIG.onAbort;
        /**
         * Callback that fires when script reference was loaded successfully.
         *
         * @default noop
         */
        this.onLoad = NGX_DEFAULT_LOAD_SCRIPT_CONFIG.onLoad;
    }
}
NgxDynamicScriptLoaderConfig.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: NgxDynamicScriptLoaderConfig, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
NgxDynamicScriptLoaderConfig.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: NgxDynamicScriptLoaderConfig });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: NgxDynamicScriptLoaderConfig, decorators: [{
            type: Injectable
        }] });

/**
 * @license
 * Copyright (c) Nelson Dominguez All Rights Reserved.
 *
 * Use of this source code is governed by a MIT-style license that
 * can found in the LICENSE file at the root of this project.
 */
/**
 *
 * @publicApi
 */
class NgxDynamicScriptLoaderModule {
    static withConfig(options) {
        return {
            ngModule: NgxDynamicScriptLoaderModule,
            providers: [
                {
                    provide: NgxDynamicScriptLoaderConfig,
                    useValue: { ...NGX_DEFAULT_LOAD_SCRIPT_CONFIG, ...options },
                },
            ],
        };
    }
}
NgxDynamicScriptLoaderModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: NgxDynamicScriptLoaderModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxDynamicScriptLoaderModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.0.2", ngImport: i0, type: NgxDynamicScriptLoaderModule });
NgxDynamicScriptLoaderModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: NgxDynamicScriptLoaderModule, providers: [NgxDynamicScriptLoaderConfig] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: NgxDynamicScriptLoaderModule, decorators: [{
            type: NgModule,
            args: [{
                    providers: [NgxDynamicScriptLoaderConfig],
                }]
        }] });

/**
 * @license
 * Copyright (c) Nelson Dominguez All Rights Reserved.
 *
 * Use of this source code is governed by a MIT-style license that
 * can found in the LICENSE file at the root of this project.
 */
/**
 * An Angular service to dynamically load and insert JavaScript modules into the DOM.
 * This service comes in handy in cases where a one wants to offset loading remote
 * JS modules from a CDN.
 *
 * @example
 * ...
 * ngOnInit() {
 *  const scriptRefs: ScriptRef[] = [
 *   {name: 'MyAwesomeScript', src: 'http://cdn.cloudflare.com/my-awesome-script.js'}
 *   {name: 'AnotherScript', src: 'http://cdn.cloudflare.com/another-script.js'}
 *  ];
 *
 *  // Load the first scriptRef
 *  this.dynamicScriptLoader
 *    .loadScript(scriptRefs[0])
 *    .subscribe((script) => {
 *      console.log(script);
 *      // Output: {name: "MyAwesomeScript", module: function () {}}
 *    });
 *
 *
 *  // Load both script refs
 *  this.dynamicScriptLoader
 *    .loadScript(...scriptRefs)
 *    .subscribe((scripts) => {
 *      console.log(scripts)
 *      // Output: [{name: "MyAwesomeScript", module: function() {}}, {name: "AnotherScript", module: function() {}}]
 *    })
 * }
 *
 *
 * @publicApi
 */
class NgxDynamicScriptLoader {
    /**
     * Initializes an Angular service that provides methods to fetch remote JS script files.
     *
     * @param {RendererFactory2} renderer2Factory Factory to create a custom render.
     * @param {Document} doc Main renderering context.
     */
    constructor(renderer2Factory, config, doc) {
        this.renderer2Factory = renderer2Factory;
        this.config = config;
        this.doc = doc;
        this.scripts = new Map();
        this.renderer2 = renderer2Factory.createRenderer(doc, null);
    }
    /**
     * Load a list of {@link NgxScriptRef} objects.
     * @param scriptRefs A list of script references to fetch.
     * @returns {Observable<NgxScriptLoaded[]>} An observable stream that when subscribed to emits
     *  the loaded script references.
     */
    loadScripts(...scriptRefs) {
        const scriptRefs$ = scriptRefs.map((scriptRef) => this.loadScript(scriptRef));
        return forkJoin(scriptRefs$);
    }
    /**
     * Load a single {@link NgxScriptRef} object.
     * @param {NgxScriptRef} scriptRef Options to customize the script loading process.
     * @returns {Observable<NgxScriptLoaded>} Observable that when subscribed to emits the script object.
     */
    loadScript(scriptRef) {
        return new Observable((subscriber) => {
            const { name, src, ...scriptRefConfig } = scriptRef;
            const { async, skipError, skipAbort } = { ...this.config, ...scriptRefConfig };
            if (this.isLoaded(name)) {
                // The script reference was already fetched from the remote url.
                // We can already next the observable with the script ref object
                // complete the stream.
                const script = this.get(name) ?? this.get(src);
                subscriber.next(script);
                subscriber.complete();
            }
            const onLoadCallback = (evt) => {
                const module = window != null ? self[name] : undefined;
                const result = { fetched: true, loaded: true, name, src, module };
                if (scriptRef.onLoad) {
                    // Trigger provided `onLoad` callback.
                    scriptRef.onLoad(result);
                }
                this.scripts.set(name, result);
                subscriber.next(result);
                subscriber.complete();
            };
            const onAbortCallback = (reason) => {
                if (skipAbort === true) {
                    // The user prefers to let the script fail silently `onabort` event.
                    const result = { fetched: true, loaded: false, name, src };
                    subscriber.next(result);
                    subscriber.complete();
                }
                else {
                    if (scriptRef.onAbort) {
                        // Trigger provided `onAbort` callback.
                        scriptRef.onAbort(reason);
                    }
                    subscriber.error(reason);
                }
            };
            const onErrorCallback = (reason) => {
                if (skipError === true) {
                    const result = { fetched: true, loaded: false, name, src };
                    subscriber.next(result);
                    subscriber.complete();
                }
                else {
                    if (scriptRef.onError) {
                        // Trigger provided `onError` callback.
                        scriptRef.onError(reason);
                    }
                    subscriber.error(reason);
                }
            };
            const script = this.createScriptElement(src, async);
            script.onload = onLoadCallback;
            script.onabort = onAbortCallback;
            script.onerror = onErrorCallback;
            this.appendScript(script);
        });
    }
    /**
     * Gets the {@link NgxDynamicScriptLoaded} by provided name if it exists - returns undefined otherwise.
     * @param {string} name The script's name to find.
     * @returns {NgxDynamicScriptLoaded | undefined} The script object if it exists, undefined otherwise.
     */
    get(name) {
        return this.scripts.get(name);
    }
    /**
     * Verify whether a script was already fetched and/or loaded from a remote server.
     * @param {string} name The name or url of the script to check.
     * @returns {boolean} Whether the script exists and the `loaded` property is set to true.
     */
    isLoaded(name) {
        if (!this.exists(name))
            return false;
        const script = this.get(name);
        return script.loaded === true;
    }
    /**
     * Verify whether a script by provided name exists.
     * @param {string} name The script's name to check.
     * @returns {boolean} Whether script by provided name exist.
     */
    exists(name) {
        return this.scripts.has(name);
    }
    appendScript(script) {
        return this.doc.getElementsByTagName('head')[0].appendChild(script);
    }
    createScriptElement(src, async = true) {
        const script = this.renderer2.createElement('script');
        script.type = 'text/javascript';
        script.src = src;
        script.async = async;
        return script;
    }
}
NgxDynamicScriptLoader.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: NgxDynamicScriptLoader, deps: [{ token: i0.RendererFactory2 }, { token: NgxDynamicScriptLoaderConfig }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Injectable });
NgxDynamicScriptLoader.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: NgxDynamicScriptLoader, providedIn: NgxDynamicScriptLoaderModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: NgxDynamicScriptLoader, decorators: [{
            type: Injectable,
            args: [{ providedIn: NgxDynamicScriptLoaderModule }]
        }], ctorParameters: function () { return [{ type: i0.RendererFactory2 }, { type: NgxDynamicScriptLoaderConfig }, { type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }]; } });

/**
 * @license
 * Copyright (c) Nelson Dominguez All Rights Reserved.
 *
 * Use of this source code is governed by a MIT-style license that
 * can found in the LICENSE file at the root of this project.
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NGX_DEFAULT_LOAD_SCRIPT_CONFIG, NgxDynamicScriptLoader, NgxDynamicScriptLoaderConfig, NgxDynamicScriptLoaderModule };
//# sourceMappingURL=letterflow-ngx-dynamic-script-loader.mjs.map
